function varargout = arrow(start,stop,varargin)

%  ARROW(start,stop,varargin)  draw a line with an arrow pointing from
%                           start to stop
%  Draw a line with an  arrow at the end of a line
%  It is assumed that the axis limits are already set
%  inputs:
%    start is the x,y point where the line starts
%    stop is the x,y point where the line stops
%    optional arguments
%       scalefactor: multiplier to internally computed scale factor. 
%          Makes arrow head larger?
%      varargin: all the rest of the options are passed to plot function
%  outputs:
%     (optional) arguments returned by plot
%       8/4/93    Jeffery Faneuff
%       Copyright (c) 1988-93 by the MathWorks, Inc.
%  Modifications by REA Copyright (c) 2007 by Aprend Technology

nreqargs = 2;
assert(numel(start)==2);
assert(numel(stop)==2);
start = start(:);
stop = stop(:);
assert(nargin>=nreqargs);

xl = get(gca,'xlim');
yl = get(gca,'ylim');
xd = xl(2)-xl(1);        % this sets the scale for the arrow size
yd = yl(2)-yl(1);        % thus enabling the arrow to appear in correct 
scale = (xd + yd) / 2;   % proportion to the current axis
scalefactor = 1;
  % process the optional arguments

i=1;
if(nargin>nreqargs)
  while(i<=size(varargin,2))
     switch lower(varargin{i})
     case 'scalefactor';         scalefactor=varargin{i+1};     i=i+1;
     otherwise
        break
     end
     i=i+1;
  end
end

scale = scalefactor*scale;
hold on
axis(axis)

xdif = stop(1) - start(1);
ydif = stop(2) - start(2);

theta = atan(ydif/xdif);  % the angle has to point according to the slope

if(xdif>=0)
  scale = -scale;
end

xx = [start(1), stop(1),(stop(1)+0.02*scale*cos(theta+pi/4)),NaN,stop(1),... 
(stop(1)+0.02*scale*cos(theta-pi/4))]';
yy = [start(2), stop(2), (stop(2)+0.02*scale*sin(theta+pi/4)),NaN,stop(2),... 
(stop(2)+0.02*scale*sin(theta-pi/4))]';

if nargout
    varargout{1:nargout} = plot(xx,yy,varargin{i:end});
else
    plot(xx,yy,varargin{i:end});
end

hold off